Class: FinnhubRuby::CompanyProfile

Inherits:
Object
  • Object
show all
Defined in:
lib/finnhub_ruby/models/company_profile.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CompanyProfile

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/finnhub_ruby/models/company_profile.rb', line 177

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FinnhubRuby::CompanyProfile` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FinnhubRuby::CompanyProfile`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'address')
    self.address = attributes[:'address']
  end

  if attributes.key?(:'city')
    self.city = attributes[:'city']
  end

  if attributes.key?(:'country')
    self.country = attributes[:'country']
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  end

  if attributes.key?(:'cusip')
    self.cusip = attributes[:'cusip']
  end

  if attributes.key?(:'sedol')
    self.sedol = attributes[:'sedol']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'exchange')
    self.exchange = attributes[:'exchange']
  end

  if attributes.key?(:'ggroup')
    self.ggroup = attributes[:'ggroup']
  end

  if attributes.key?(:'gind')
    self.gind = attributes[:'gind']
  end

  if attributes.key?(:'gsector')
    self.gsector = attributes[:'gsector']
  end

  if attributes.key?(:'gsubind')
    self.gsubind = attributes[:'gsubind']
  end

  if attributes.key?(:'isin')
    self.isin = attributes[:'isin']
  end

  if attributes.key?(:'naics_national_industry')
    self.naics_national_industry = attributes[:'naics_national_industry']
  end

  if attributes.key?(:'naics')
    self.naics = attributes[:'naics']
  end

  if attributes.key?(:'naics_sector')
    self.naics_sector = attributes[:'naics_sector']
  end

  if attributes.key?(:'naics_subsector')
    self.naics_subsector = attributes[:'naics_subsector']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'phone')
    self.phone = attributes[:'phone']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'ticker')
    self.ticker = attributes[:'ticker']
  end

  if attributes.key?(:'weburl')
    self.weburl = attributes[:'weburl']
  end

  if attributes.key?(:'ipo')
    self.ipo = attributes[:'ipo']
  end

  if attributes.key?(:'market_capitalization')
    self.market_capitalization = attributes[:'market_capitalization']
  end

  if attributes.key?(:'share_outstanding')
    self.share_outstanding = attributes[:'share_outstanding']
  end

  if attributes.key?(:'employee_total')
    self.employee_total = attributes[:'employee_total']
  end

  if attributes.key?(:'logo')
    self. = attributes[:'logo']
  end

  if attributes.key?(:'finnhub_industry')
    self.finnhub_industry = attributes[:'finnhub_industry']
  end
end

Instance Attribute Details

#addressObject

Address of company’s headquarter.



18
19
20
# File 'lib/finnhub_ruby/models/company_profile.rb', line 18

def address
  @address
end

#cityObject

City of company’s headquarter.



21
22
23
# File 'lib/finnhub_ruby/models/company_profile.rb', line 21

def city
  @city
end

#countryObject

Country of company’s headquarter.



24
25
26
# File 'lib/finnhub_ruby/models/company_profile.rb', line 24

def country
  @country
end

#currencyObject

Currency used in company filings.



27
28
29
# File 'lib/finnhub_ruby/models/company_profile.rb', line 27

def currency
  @currency
end

#cusipObject

CUSIP number.



30
31
32
# File 'lib/finnhub_ruby/models/company_profile.rb', line 30

def cusip
  @cusip
end

#descriptionObject

Company business summary.



36
37
38
# File 'lib/finnhub_ruby/models/company_profile.rb', line 36

def description
  @description
end

#employee_totalObject

Number of employee.



93
94
95
# File 'lib/finnhub_ruby/models/company_profile.rb', line 93

def employee_total
  @employee_total
end

#exchangeObject

Listed exchange.



39
40
41
# File 'lib/finnhub_ruby/models/company_profile.rb', line 39

def exchange
  @exchange
end

#finnhub_industryObject

Finnhub industry classification.



99
100
101
# File 'lib/finnhub_ruby/models/company_profile.rb', line 99

def finnhub_industry
  @finnhub_industry
end

#ggroupObject

GICS industry group.



42
43
44
# File 'lib/finnhub_ruby/models/company_profile.rb', line 42

def ggroup
  @ggroup
end

#gindObject

GICS industry.



45
46
47
# File 'lib/finnhub_ruby/models/company_profile.rb', line 45

def gind
  @gind
end

#gsectorObject

GICS sector.



48
49
50
# File 'lib/finnhub_ruby/models/company_profile.rb', line 48

def gsector
  @gsector
end

#gsubindObject

GICS sub-industry.



51
52
53
# File 'lib/finnhub_ruby/models/company_profile.rb', line 51

def gsubind
  @gsubind
end

#ipoObject

IPO date.



84
85
86
# File 'lib/finnhub_ruby/models/company_profile.rb', line 84

def ipo
  @ipo
end

#isinObject

ISIN number.



54
55
56
# File 'lib/finnhub_ruby/models/company_profile.rb', line 54

def isin
  @isin
end

#logoObject

Logo image.



96
97
98
# File 'lib/finnhub_ruby/models/company_profile.rb', line 96

def 
  
end

#market_capitalizationObject

Market Capitalization.



87
88
89
# File 'lib/finnhub_ruby/models/company_profile.rb', line 87

def market_capitalization
  @market_capitalization
end

#naicsObject

NAICS industry.



60
61
62
# File 'lib/finnhub_ruby/models/company_profile.rb', line 60

def naics
  @naics
end

#naics_national_industryObject

NAICS national industry.



57
58
59
# File 'lib/finnhub_ruby/models/company_profile.rb', line 57

def naics_national_industry
  @naics_national_industry
end

#naics_sectorObject

NAICS sector.



63
64
65
# File 'lib/finnhub_ruby/models/company_profile.rb', line 63

def naics_sector
  @naics_sector
end

#naics_subsectorObject

NAICS subsector.



66
67
68
# File 'lib/finnhub_ruby/models/company_profile.rb', line 66

def naics_subsector
  @naics_subsector
end

#nameObject

Company name.



69
70
71
# File 'lib/finnhub_ruby/models/company_profile.rb', line 69

def name
  @name
end

#phoneObject

Company phone number.



72
73
74
# File 'lib/finnhub_ruby/models/company_profile.rb', line 72

def phone
  @phone
end

#sedolObject

Sedol number.



33
34
35
# File 'lib/finnhub_ruby/models/company_profile.rb', line 33

def sedol
  @sedol
end

#share_outstandingObject

Number of oustanding shares.



90
91
92
# File 'lib/finnhub_ruby/models/company_profile.rb', line 90

def share_outstanding
  @share_outstanding
end

#stateObject

State of company’s headquarter.



75
76
77
# File 'lib/finnhub_ruby/models/company_profile.rb', line 75

def state
  @state
end

#tickerObject

Company symbol/ticker as used on the listed exchange.



78
79
80
# File 'lib/finnhub_ruby/models/company_profile.rb', line 78

def ticker
  @ticker
end

#weburlObject

Company website.



81
82
83
# File 'lib/finnhub_ruby/models/company_profile.rb', line 81

def weburl
  @weburl
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/finnhub_ruby/models/company_profile.rb', line 102

def self.attribute_map
  {
    :'address' => :'address',
    :'city' => :'city',
    :'country' => :'country',
    :'currency' => :'currency',
    :'cusip' => :'cusip',
    :'sedol' => :'sedol',
    :'description' => :'description',
    :'exchange' => :'exchange',
    :'ggroup' => :'ggroup',
    :'gind' => :'gind',
    :'gsector' => :'gsector',
    :'gsubind' => :'gsubind',
    :'isin' => :'isin',
    :'naics_national_industry' => :'naicsNationalIndustry',
    :'naics' => :'naics',
    :'naics_sector' => :'naicsSector',
    :'naics_subsector' => :'naicsSubsector',
    :'name' => :'name',
    :'phone' => :'phone',
    :'state' => :'state',
    :'ticker' => :'ticker',
    :'weburl' => :'weburl',
    :'ipo' => :'ipo',
    :'market_capitalization' => :'marketCapitalization',
    :'share_outstanding' => :'shareOutstanding',
    :'employee_total' => :'employeeTotal',
    :'logo' => :'logo',
    :'finnhub_industry' => :'finnhubIndustry'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



366
367
368
# File 'lib/finnhub_ruby/models/company_profile.rb', line 366

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



170
171
172
173
# File 'lib/finnhub_ruby/models/company_profile.rb', line 170

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/finnhub_ruby/models/company_profile.rb', line 136

def self.openapi_types
  {
    :'address' => :'String',
    :'city' => :'String',
    :'country' => :'String',
    :'currency' => :'String',
    :'cusip' => :'String',
    :'sedol' => :'String',
    :'description' => :'String',
    :'exchange' => :'String',
    :'ggroup' => :'String',
    :'gind' => :'String',
    :'gsector' => :'String',
    :'gsubind' => :'String',
    :'isin' => :'String',
    :'naics_national_industry' => :'String',
    :'naics' => :'String',
    :'naics_sector' => :'String',
    :'naics_subsector' => :'String',
    :'name' => :'String',
    :'phone' => :'String',
    :'state' => :'String',
    :'ticker' => :'String',
    :'weburl' => :'String',
    :'ipo' => :'Date',
    :'market_capitalization' => :'Float',
    :'share_outstanding' => :'Float',
    :'employee_total' => :'Integer',
    :'logo' => :'String',
    :'finnhub_industry' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
# File 'lib/finnhub_ruby/models/company_profile.rb', line 318

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      address == o.address &&
      city == o.city &&
      country == o.country &&
      currency == o.currency &&
      cusip == o.cusip &&
      sedol == o.sedol &&
      description == o.description &&
      exchange == o.exchange &&
      ggroup == o.ggroup &&
      gind == o.gind &&
      gsector == o.gsector &&
      gsubind == o.gsubind &&
      isin == o.isin &&
      naics_national_industry == o.naics_national_industry &&
      naics == o.naics &&
      naics_sector == o.naics_sector &&
      naics_subsector == o.naics_subsector &&
      name == o.name &&
      phone == o.phone &&
      state == o.state &&
      ticker == o.ticker &&
      weburl == o.weburl &&
      ipo == o.ipo &&
      market_capitalization == o.market_capitalization &&
      share_outstanding == o.share_outstanding &&
      employee_total == o.employee_total &&
       == o. &&
      finnhub_industry == o.finnhub_industry
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
# File 'lib/finnhub_ruby/models/company_profile.rb', line 394

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    FinnhubRuby.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



463
464
465
466
467
468
469
470
471
472
473
474
475
# File 'lib/finnhub_ruby/models/company_profile.rb', line 463

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
# File 'lib/finnhub_ruby/models/company_profile.rb', line 373

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


353
354
355
# File 'lib/finnhub_ruby/models/company_profile.rb', line 353

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



359
360
361
# File 'lib/finnhub_ruby/models/company_profile.rb', line 359

def hash
  [address, city, country, currency, cusip, sedol, description, exchange, ggroup, gind, gsector, gsubind, isin, naics_national_industry, naics, naics_sector, naics_subsector, name, phone, state, ticker, weburl, ipo, market_capitalization, share_outstanding, employee_total, , finnhub_industry].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



305
306
307
308
# File 'lib/finnhub_ruby/models/company_profile.rb', line 305

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



439
440
441
# File 'lib/finnhub_ruby/models/company_profile.rb', line 439

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



445
446
447
448
449
450
451
452
453
454
455
456
457
# File 'lib/finnhub_ruby/models/company_profile.rb', line 445

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end
    
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



433
434
435
# File 'lib/finnhub_ruby/models/company_profile.rb', line 433

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



312
313
314
# File 'lib/finnhub_ruby/models/company_profile.rb', line 312

def valid?
  true
end